TransactionSerializable class abstract

Transaction Serializable

A serializable transaction interface.

Mixed-in types

Constructors

TransactionSerializable()
Creates a serializable transaction object.
const

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
serialize([TransactionSerializableConfig? config]) → Iterable<int>
Serialises a transaction into a buffer.
inherited
serializeMessage() → Iterable<int>
Serialises a transaction message into a buffer.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited