TransactionSerializableConfig class

Transaction Serializable Config

Constructors

TransactionSerializableConfig({bool requireAllSignatures = true, bool verifySignatures = true})
Creates a configuration object for TransactionSerializableMixin.serialize.
const

Properties

hashCode → int
The hash code for this object.
no setterinherited
requireAllSignatures → bool
Require all transaction signatures be present (default: true).
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
verifySignatures → bool
Verify provided signatures (default: true).
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited